import { BaseEntity, BeforeInsert, BeforeUpdate, Column, PrimaryGeneratedColumn } from 'typeorm';

export abstract class CommonEntity extends BaseEntity {
  @Column({
    type: 'double precision',
    default: 1,
  })
  created_at: number;

  @Column({
    type: 'double precision',
    default: 1,
  })
  updated_at: number;

  @PrimaryGeneratedColumn('identity', {
    type: 'bigint',
  })
  id: string;

  private readonly unixTimestamp = Date.now() + performance.now();

  @BeforeInsert()
  protected insertDates() {
    console.log('🚀 ~  performance.now():', performance.now());

    this.created_at = this.unixTimestamp;
    this.updated_at = this.unixTimestamp;
  }

  @BeforeUpdate()
  protected updateDates() {
    this.updated_at = this.unixTimestamp;
  }
}
