import { Column, Entity } from 'typeorm';
import { CommonEntity } from './_common.entity';

@Entity('post')
export class PostEntity extends CommonEntity {
  @Column({
    type: 'bigint',
  })
  user_id: string;

  @Column({
    type: 'int',
    default: 0,
  })
  is_review: number;

  @Column({
    type: 'int',
    default: 0,
  })
  auto_post_type: number;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  branch_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  brand_id: string;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  restaurant_id: string;

  @Column({
    type: 'smallint',
    default: 0, // 0 - newsfeed, 1 - user, 2 - fanpage, 3 - group
  })
  post_type: number;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  target_id: number;

  /**
   * Tiêu đề bài viết
   */
  @Column({
    type: 'varchar',
    nullable: true,
  })
  title: string;

  /**
   * Nội dung bài viết
   */
  @Column({
    type: 'text',
    nullable: true,
  })
  content: string;

  @Column({
    type: 'text',
    nullable: true,
  })
  medias: string;

  @Column({
    type: 'real',
    nullable: true,
  })
  average_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  food_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  price_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  spatial_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  hygiene_rating: number;

  @Column({
    type: 'real',
    nullable: true,
  })
  service_rating: number;

  @Column({
    type: 'text',
    nullable: true,
  })
  tag: string;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_comment: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_love: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_wow: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_sad: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_angry: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_value: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_nothing: number;

  @Column({
    type: 'int',
    default: 0,
  })
  value: number;

  @Column({
    type: 'int',
    default: 0,
  })
  action_level: number;

  @Column({
    type: 'int',
    default: 0,
  })
  no_of_share: number;

  @Column({
    type: 'smallint',
    default: 0,
  })
  is_share: number;

  @Column({
    type: 'bigint',
    nullable: true,
  })
  post_share_id: string;

  /**
   *View của bài viết
   */
  @Column({
    type: 'smallint',
    default: 0,
  })
  view: number;

  /**
   *Bài viết đã được detect hay chưa
   */
  @Column({
    type: 'smallint',
    default: 0,
  })
  is_detect: number;

  /**
   *Bài viết có phải là bài đăng avatar không
   */
  @Column({
    type: 'smallint',
    default: 0,
  })
  is_avatar_post: number;

  //Tình trạng bài viết 0-waiting, 1-accepted, 2-revoke
  @Column({
    type: 'smallint',
    default: 1,
  })
  target_status: number;

  @Column({
    type: 'bigint',
    default: [],
    array: true,
  })
  card_tag: string[];

  @Column({
    type: 'text',
    nullable: true,
  })
  thumbnail: string;

  /**
   *Trạng thái của bài viết
   * 0: Bình thường
   * 1: Bị an
   * 2: Bị xóa
   * 3: Bị khóa
   */
  @Column({
    type: 'smallint',
    default: 0,
  })
  status: number;
}
